@@ -849,7 +849,7 @@ class BaseExperiment:
             self.save_ckpt(**subject)
         del self.stack 
         self.stack = []
-
+    """
     def delete_saved_model(
         self,
         model_type : Union["pl.LightningModule", "nn.Module", "BaseEstimator"],
@@ -875,7 +875,7 @@ class BaseExperiment:
         shutil.rmtree(path=ckpt_dir)
         shutil.rmtree(path=jsonlog_dir)
         shutil.rmtree(path=tensorboard_dir)
-        
+    """    
 
             
     def best_ckpt_thus_far(
@@ -1015,18 +1015,10 @@ class BaseExperiment:
         self,
         model: Union["pl.LightningModule", "BaseEstimator"],
         hparams : dict,
-        length_limit : int = 250,
-        subtract : int = 30
     )->str: 
         r"""Method for generating metadata of the experiment.
         
         Args:
-            
-            length_limit (int): Maximum tolerance for the length of the string. 
-                Default: ``250``
-            
-            subtract (int): Width of the wiggle room for sanity. 
-                Default: ``30``
 
             model (`LightningModule` or `BaseEstimator`): Class of model type. 
 
@@ -1046,32 +1038,6 @@ class BaseExperiment:
         
         model_metadata = f"{model.__class__.__name__}-{hparams_str}" 
 
-        #################################################
-        # Shorten the length of model_metadata
-        # when the name is too long. This is done
-        # by shortening the 'hparams' part in 
-        # metadata. 
-        # 'hparams' part will now then
-        # only contain value for each key.
-        # The order for the values are as per
-        # the lexicographic ordering of the keys.
-        # If it is still too long, take adequate amount
-        # of text from 'hparams' part.
-        #################################################
-        if len(model_metadata) > length_limit:
-            hparams_sorted_by_key = sorted(hparams.items())
-            truncated_hparams_str = ""
-            for key, value in hparams_sorted_by_key:
-                add_ = str(value).replace(".","d") + "-"
-                truncated_hparams_str += add_
-            
-            new_metadata = f"{model.__class__.__name__}-{truncated_hparams_str}"   
-            if len(new_metadata) > length_limit:
-                logger.info(f"The length of the metadata is too long due to long hyperparameter specs. \
-                    We will take the first {length_limit-subtract} letters from the hyperparameter part.")
-                new_metadata = f"{model.__class__.__name__}-{hparams_str[:length_limit-subtract]}" 
-
-                model_metadata = new_metadata
         return model_metadata
    
     def get_hparams(self, model):
