@@ -266,8 +266,6 @@ class BaseNet(pl.LightningModule):
                                         momentum=self.hparams.momentum,
                                         weight_decay=self.hparams.weight_decay)
 
-        if 'scheduler' not in self.config.keys():
-            self.config.update({'scheduler' : None})
 
         scheduler_dict = {
             "scheduler" : self.get_scheduler(optimizer=optimizer, scheduler_class=self.scheduler_config["scheduler"], **(self.scheduler_config["scheduler_config"])),
@@ -513,8 +511,6 @@ class ConvNet(pl.LightningModule):
                                         momentum=self.hparams.momentum,
                                         weight_decay=self.hparams.weight_decay)
 
-        if 'scheduler' not in self.config.keys():
-            self.config.update({'scheduler' : None})
 
         scheduler_dict = {
             "scheduler" : self.get_scheduler(optimizer=optimizer, scheduler_class=self.scheduler_config["scheduler"], **(self.scheduler_config["scheduler_config"])),
@@ -743,9 +739,6 @@ class SegNet(pl.LightningModule):
                                         momentum=self.hparams.momentum,
                                         weight_decay=self.hparams.weight_decay)
 
-        if 'scheduler' not in self.config.keys():
-            self.config.update({'scheduler' : None})
-
         scheduler_dict = {
             "scheduler" : self.get_scheduler(optimizer=optimizer, scheduler_class=self.scheduler_config["scheduler"], **(self.scheduler_config["scheduler_config"])),
             "interval" : "step"
